@@ -31,44 +31,45 @@
 using namespace std;
 
 /**
-  * Return the PkEnumGroup of the give group string.
-  */
+ * Return the PkEnumGroup of the give group string.
+ */
 PkGroupEnum get_enum_group(string group);
 
 /**
-  * Return the changelog and extract details about the changes.
-  */
-string fetchChangelogData(AptCacheFile &CacheFile,
-                          pkgAcquire &Fetcher,
-                          pkgCache::VerIterator Ver,
-                          pkgCache::VerIterator currver,
-                          string *update_text,
-                          string *updated,
-                          string *issued);
+ * Return the changelog and extract details about the changes.
+ */
+string fetchChangelogData(
+    AptCacheFile &CacheFile,
+    pkgAcquire &Fetcher,
+    pkgCache::VerIterator Ver,
+    pkgCache::VerIterator currver,
+    string *update_text,
+    string *updated,
+    string *issued);
 
 /**
-  * Returns a list of links pairs url;description for CVEs
-  */
-GPtrArray* getCVEUrls(const string &changelog);
+ * Returns a list of links pairs url;description for CVEs
+ */
+GPtrArray *getCVEUrls(const string &changelog);
 
 /**
-  * Returns a list of links pairs url;description for Debian and Ubuntu bugs
-  */
-GPtrArray* getBugzillaUrls(const string &changelog);
+ * Returns a list of links pairs url;description for Debian and Ubuntu bugs
+ */
+GPtrArray *getBugzillaUrls(const string &changelog);
 
 /**
-  * Return if the given string ends with the other
-  */
+ * Return if the given string ends with the other
+ */
 bool ends_with(const string &str, const char *end);
 
 /**
-  * Return if the given string starts with the other
-  */
+ * Return if the given string starts with the other
+ */
 bool starts_with(const string &str, const char *end);
 
 /**
-  * Return true if the given package name is on the list of packages that require a restart
-  */
+ * Return true if the given package name is on the list of packages that require a restart
+ */
 bool utilRestartRequired(const string &packageName);
 
 /**
@@ -78,15 +79,15 @@ bool utilRestartRequired(const string &packageName);
 string utilBuildPackageOriginId(pkgCache::VerFileIterator vf);
 
 /**
-  * Return an utf8 string
-  */
+ * Return an utf8 string
+ */
 const char *toUtf8(const char *str);
 
 /**
-  * Changelog dates are in format RFC2822/RFC5322 compatible:
-  * "day-of-week, dd month yyyy hh:mm:ss +zzzz"
-  * Parses and converts to ISO8601 respecting the original timezone
-  */
-string changelogDateToIso8601 (const string &date_str);
+ * Changelog dates are in format RFC2822/RFC5322 compatible:
+ * "day-of-week, dd month yyyy hh:mm:ss +zzzz"
+ * Parses and converts to ISO8601 respecting the original timezone
+ */
+string changelogDateToIso8601(const string &date_str);
 
 #endif
