@@ -171,7 +171,7 @@ class PackageKitPisiBackend(PackageKitBaseBackend, PackagekitPackage):
                 else ''
 
             self.details(pkg_id, '', ",".join(pkg.license), group, pkg.description,
-                         homepage, pkg.packageSize)
+                         homepage, pkg.packageSize, None)
         else:
             self.error(ERROR_PACKAGE_NOT_FOUND, "Package was not found")
 
