@@ -31,48 +31,48 @@ static gboolean opt_download_only = FALSE;
 static gboolean opt_allow_downgrade = FALSE;
 static gboolean opt_allow_reinstall = FALSE;
 static gboolean opt_allow_untrusted = FALSE;
-static gboolean opt_autoremove = FALSE;
+static gboolean opt_no_autoremove = FALSE;
 static gint opt_cache_age = -1;
 
 static const GOptionEntry option_download_only[] = {
 	{ "download-only", 'd', 0, G_OPTION_ARG_NONE, &opt_download_only,
 		/* TRANSLATORS: command line argument, do we just download or apply changes */
-	  N_("Prepare the transaction by downloading packages only"), NULL },
+		N_("Prepare the transaction by downloading packages only"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
 static const GOptionEntry option_allow_downgrade[] = {
 	{ "allow-downgrade", 0, 0, G_OPTION_ARG_NONE, &opt_allow_downgrade,
 		/* TRANSLATORS: command line argument, do we allow package downgrades */
-	  N_("Allow package downgrades"), NULL },
+		N_("Allow package downgrades"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
 static const GOptionEntry option_allow_reinstall[] = {
 	{ "allow-reinstall", 0, 0, G_OPTION_ARG_NONE, &opt_allow_reinstall,
 		/* TRANSLATORS: command line argument, do we allow package re-installations */
-	  N_("Allow package re-installations"), NULL },
+		N_("Allow package re-installations"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
 static const GOptionEntry option_allow_untrusted[] = {
 	{ "allow-untrusted", 0, 0, G_OPTION_ARG_NONE, &opt_allow_untrusted,
 		/* TRANSLATORS: command line argument */
-	  N_("Allow installation of untrusted packages"), NULL },
+		N_("Allow installation of untrusted packages"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
-static const GOptionEntry option_autoremove[] = {
-	{ "autoremove", 0, 0, G_OPTION_ARG_NONE, &opt_autoremove,
+static const GOptionEntry option_no_autoremove[] = {
+	{ "no-autoremove", 0, 0, G_OPTION_ARG_NONE, &opt_no_autoremove,
 		/* TRANSLATORS: command line argument */
-	  N_("Automatically remove unused dependencies"), NULL },
+		N_("Do not automatically remove unused dependencies"), NULL },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
 static const GOptionEntry option_cache_age[] = {
 	{ "cache-age", 'c', 0, G_OPTION_ARG_INT, &opt_cache_age,
 		/* TRANSLATORS: command line argument */
-	  N_("Maximum metadata cache age in seconds"), N_("SECONDS") },
+		N_("Maximum metadata cache age in seconds (default: 3 days)"), N_("SECONDS") },
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
@@ -88,8 +88,8 @@ pkgc_manage_reset_options (void)
 	opt_allow_downgrade = FALSE;
 	opt_allow_reinstall = FALSE;
 	opt_allow_untrusted = FALSE;
-	opt_autoremove = FALSE;
-	opt_cache_age = -1;
+	opt_no_autoremove = FALSE;
+	opt_cache_age = PKGC_DEFAULT_CACHE_AGE_SEC;
 }
 
 /**
@@ -99,14 +99,16 @@ pkgc_manage_reset_options (void)
  * Apply the parsed option flags to the context.
  */
 static void
-pkgc_manage_apply_options (PkgctlContext *ctx)
+pkgc_manage_apply_options (PkgcliContext *ctx)
 {
 	ctx->only_download = opt_download_only;
 	ctx->allow_downgrade = opt_allow_downgrade;
 	ctx->allow_reinstall = opt_allow_reinstall;
 	ctx->allow_untrusted = opt_allow_untrusted;
-	if (opt_cache_age >= 0)
-		ctx->cache_age = opt_cache_age;
+	if (opt_cache_age == 0)
+		ctx->cache_age = 1; /* shortest possible cache-age, 0 is not allowed */
+	else
+		ctx->cache_age = (opt_cache_age < 0)? G_MAXUINT : (guint)opt_cache_age;
 
 	pkgc_context_apply_settings (ctx);
 }
@@ -117,12 +119,12 @@ pkgc_manage_apply_options (PkgctlContext *ctx)
 static void
 pkgc_manage_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-	PkgctlContext *ctx = user_data;
+	PkgcliContext *ctx = user_data;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(PkResults) results = NULL;
 	g_autoptr(PkError) pk_error = NULL;
 
-	ctx->exit_code = PKGCTL_EXIT_SUCCESS;
+	ctx->exit_code = PKGC_EXIT_SUCCESS;
 	results = pk_task_generic_finish (PK_TASK (source_object), res, &error);
 
 	if (ctx->progressbar != NULL && ctx->is_tty)
@@ -130,7 +132,7 @@ pkgc_manage_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpoi
 
 	if (error) {
 		pkgc_print_error (ctx, "%s", error->message);
-		ctx->exit_code = PKGCTL_EXIT_TRANSACTION_FAILED;
+		ctx->exit_code = PKGC_EXIT_TRANSACTION_FAILED;
 
 		goto out;
 	}
@@ -142,7 +144,7 @@ pkgc_manage_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpoi
 	pk_error = pk_results_get_error_code (results);
 	if (pk_error) {
 		pkgc_print_error (ctx, "%s", pk_error_get_details (pk_error));
-		ctx->exit_code = PKGCTL_EXIT_TRANSACTION_FAILED;
+		ctx->exit_code = PKGC_EXIT_TRANSACTION_FAILED;
 	} else {
 		g_autoptr(GPtrArray) pkgs = NULL;
 		g_autoptr(GPtrArray) tas = NULL;
@@ -181,7 +183,7 @@ out:
  * Refresh package metadata cache.
  */
 static gint
-pkgc_refresh (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_refresh (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	gboolean force = FALSE;
 	g_autoptr(GOptionContext) option_context = NULL;
@@ -192,12 +194,12 @@ pkgc_refresh (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[force]",
-		/* TRANSLATORS: Description for pkgctl refresh */
+		/* TRANSLATORS: Description for pkgcli refresh */
 		_("Refresh the package metadata cache."));
 	g_option_context_add_main_entries (option_context, option_cache_age, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Check for force flag */
 	if (argc >= 2 && strcmp (argv[1], "force") == 0) {
@@ -218,7 +220,7 @@ pkgc_refresh (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 
 	g_main_loop_run (ctx->loop);
 
-	if (ctx->exit_code == PKGCTL_EXIT_SUCCESS)
+	if (ctx->exit_code == PKGC_EXIT_SUCCESS)
 		pkgc_print_success (ctx, _("Package metadata refreshed"));
 
 	return ctx->exit_code;
@@ -230,7 +232,7 @@ pkgc_refresh (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Install packages or local package files.
  */
 static gint
-pkgc_install (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_install (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	gboolean has_files;
 	g_autoptr(GError) error = NULL;
@@ -242,33 +244,32 @@ pkgc_install (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl install */
+		/* TRANSLATORS: Description for pkgcli install */
 		_("Install one or more packages or local package files."));
 
 	g_option_context_add_main_entries (option_context, option_download_only, NULL);
 	g_option_context_add_main_entries (option_context, option_allow_downgrade, NULL);
 	g_option_context_add_main_entries (option_context, option_allow_reinstall, NULL);
 	g_option_context_add_main_entries (option_context, option_allow_untrusted, NULL);
-	g_option_context_add_main_entries (option_context, option_autoremove, NULL);
+	g_option_context_add_main_entries (option_context, option_no_autoremove, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
-	/* Apply options to context */
+	/* apply options to context */
 	pkgc_manage_apply_options (ctx);
 
-	/* Check if we have files or package names */
+	/* check if we have files or package names */
 	has_files = FALSE;
 	for (gint i = 1; i < argc; i++) {
-		if (g_str_has_suffix (argv[i], ".rpm") || g_str_has_suffix (argv[i], ".deb") ||
-		    g_file_test (argv[i], G_FILE_TEST_EXISTS)) {
+		if (pkgc_is_local_package (argv[i])) {
 			has_files = TRUE;
 			break;
 		}
 	}
 
 	if (has_files) {
-		/* Install local files */
+		/* install local files */
 		pk_task_install_files_async (PK_TASK (ctx->task),
 					     argv + 1,
 					     ctx->cancellable,
@@ -277,33 +278,60 @@ pkgc_install (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 					     pkgc_manage_on_task_finished_cb,
 					     ctx);
 	} else {
-		/* Install packages by name - need to resolve to package IDs first */
+		/* install packages by name */
 		g_auto(GStrv) package_ids = NULL;
-		PkBitfield filters = 0;
 
-		/* Set up filters like pkcon does */
-		if (!pk_bitfield_contain (filters, PK_FILTER_ENUM_ARCH) &&
-		    !pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_ARCH))
-			pk_bitfield_add (filters, PK_FILTER_ENUM_ARCH);
+		/* assume arch filter unless specified otherwise */
+		if (!pk_bitfield_contain (ctx->filters, PK_FILTER_ENUM_ARCH) &&
+			!pk_bitfield_contain (ctx->filters, PK_FILTER_ENUM_NOT_ARCH))
+			pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_ARCH);
 
-		if (!pk_bitfield_contain (filters, PK_FILTER_ENUM_SOURCE) &&
-		    !pk_bitfield_contain (filters, PK_FILTER_ENUM_NOT_SOURCE))
-			pk_bitfield_add (filters, PK_FILTER_ENUM_NOT_SOURCE);
+		/* assume non-source packages unless specified */
+		if (!pk_bitfield_contain (ctx->filters, PK_FILTER_ENUM_SOURCE) &&
+			!pk_bitfield_contain (ctx->filters, PK_FILTER_ENUM_NOT_SOURCE))
+			pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NOT_SOURCE);
 
-		pk_bitfield_add (filters, PK_FILTER_ENUM_NEWEST);
+		pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NEWEST);
 		if (!opt_allow_reinstall)
-			pk_bitfield_add (filters, PK_FILTER_ENUM_NOT_INSTALLED);
+			pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NOT_INSTALLED);
 
-		/* Resolve package names to IDs */
-		package_ids = pkgc_resolve_packages (ctx, filters, argv + 1, &error);
+		/* resolve package names to IDs */
+		package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 		if (package_ids == NULL) {
-			if (error)
+			/* the the error was not "no package found", or we did allow reinstallations
+			 * (and therefore didn't filter out already installed packages) we show the
+			 * emitted error immediately. */
+			if (g_error_matches (error, PKGC_ERROR, PK_ERROR_ENUM_PACKAGE_NOT_FOUND) ||
+				 opt_allow_reinstall) {
 				pkgc_print_error (ctx,
-						  _("Could not find packages: %s"), error->message);
-			return PKGCTL_EXIT_FAILURE;
+							/* TRANSLATORS: There was an error finding a package
+							 * for installation. The detailed error follows. */
+							_("Could not find any available package: %s"), error->message);
+				return PKGC_EXIT_NOT_FOUND;
+			}
+
+			/* If we are here, the package may exist, but may already be installed.
+			 * Check for that to provide a better error */
+			pk_bitfield_remove (ctx->filters, PK_FILTER_ENUM_NOT_INSTALLED);
+			pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_INSTALLED);
+			package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, NULL);
+			if (package_ids == NULL) {
+				/* the package does not exist at all */
+				pkgc_print_error (ctx,
+							/* TRANSLATORS: We were unable to find a package for installation. */
+							_("Could not find any available package: %s"), error->message);
+				return PKGC_EXIT_NOT_FOUND;
+			} else {
+				/* the package exists, but is already installed */
+				pkgc_print_info (ctx,
+							_("The selected package is already installed."));
+				return PKGC_EXIT_SUCCESS;
+			}
+
+			return PKGC_EXIT_FAILURE;
 		}
 
-		/* Install packages by ID */
+		/* install packages */
 		pk_task_install_packages_async (PK_TASK (ctx->task),
 						package_ids,
 						ctx->cancellable,
@@ -323,9 +351,10 @@ pkgc_install (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Remove packages from the system.
  */
 static gint
-pkgc_remove (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_remove (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
+	g_auto(GStrv) package_ids = NULL;
 	g_autoptr(GError) error = NULL;
 
 	pkgc_manage_reset_options ();
@@ -334,47 +363,40 @@ pkgc_remove (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl remove */
+		/* TRANSLATORS: Description for pkgcli remove */
 		_("Remove one or more packages from the system."));
-	g_option_context_add_main_entries (option_context, option_autoremove, NULL);
+	g_option_context_add_main_entries (option_context, option_no_autoremove, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
-	/* Apply options to context */
+	/* apply options to context */
 	pkgc_manage_apply_options (ctx);
 
-	/* Remove packages - need to resolve to package IDs first */
-	{
-		g_auto(GStrv) package_ids = NULL;
-		PkBitfield filters = 0;
+	/* only look at installed packages */
+	pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_INSTALLED);
 
-		/* Set up filters - only look at installed packages */
-		pk_bitfield_add (filters, PK_FILTER_ENUM_INSTALLED);
-		pk_bitfield_add (filters, PK_FILTER_ENUM_NEWEST);
-
-		/* Resolve package names to IDs */
-		package_ids = pkgc_resolve_packages (ctx, filters, argv + 1, &error);
-		if (package_ids == NULL) {
-			if (error) {
-				pkgc_print_error (ctx,
-						  _("Could not find packages: %s"), error->message);
-			}
-			return PKGCTL_EXIT_FAILURE;
+	/* resolve package names to IDs */
+	package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
+	if (package_ids == NULL) {
+		if (error) {
+			pkgc_print_error (ctx,
+					  _("Could not find installed packages: %s"), error->message);
 		}
-
-		/* Remove packages */
-		pk_task_remove_packages_async (PK_TASK (ctx->task),
-					       package_ids,
-					       TRUE, /* allow deps */
-					       opt_autoremove,
-					       ctx->cancellable,
-					       pkgc_context_on_progress_cb,
-					       ctx,
-					       pkgc_manage_on_task_finished_cb,
-					       ctx);
+		return PKGC_EXIT_FAILURE;
 	}
 
+	/* remove packages */
+	pk_task_remove_packages_async (PK_TASK (ctx->task),
+				       package_ids,
+				       TRUE, /* allow deps */
+				       !opt_no_autoremove, /* autoremove */
+				       ctx->cancellable,
+				       pkgc_context_on_progress_cb,
+				       ctx,
+				       pkgc_manage_on_task_finished_cb,
+				       ctx);
+
 	g_main_loop_run (ctx->loop);
 	return ctx->exit_code;
 }
@@ -385,7 +407,7 @@ pkgc_remove (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Download packages to the specified directory without installing.
  */
 static gint
-pkgc_download (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_download (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	const char *directory = NULL;
@@ -398,10 +420,10 @@ pkgc_download (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"DIRECTORY PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl download */
+		/* TRANSLATORS: Description for pkgcli download */
 		_("Download packages to the specified directory without installing."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 3))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Apply options to context */
 	pkgc_manage_apply_options (ctx);
@@ -416,13 +438,13 @@ pkgc_download (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 					  _("Could not find packages: %s"), error->message);
 		}
 
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
 	/* Check if directory exists */
 	if (!g_file_test (directory, G_FILE_TEST_IS_DIR)) {
 		pkgc_print_error (ctx, _("Directory does not exist: %s"), directory);
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 	}
 
 	/* Download packages */
@@ -439,13 +461,20 @@ pkgc_download (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	return ctx->exit_code;
 }
 
+static gboolean
+pkgc_update_system_filter_helper (PkPackage *package, gpointer user_data)
+{
+	PkInfoEnum package_enum = pk_package_get_info (package);
+	return package_enum != PK_INFO_ENUM_BLOCKED;
+}
+
 /**
  * pkgc_update:
  *
  * Update all packages or specific packages to their latest versions.
  */
 static gint
-pkgc_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_update (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_autoptr(GError) error = NULL;
@@ -456,37 +485,51 @@ pkgc_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[PACKAGE...]",
-		/* TRANSLATORS: Description for pkgctl update */
+		/* TRANSLATORS: Description for pkgcli update */
 		_("Update all packages or specific packages to their latest versions."));
 	g_option_context_add_main_entries (option_context, option_download_only, NULL);
 	g_option_context_add_main_entries (option_context, option_allow_downgrade, NULL);
-	g_option_context_add_main_entries (option_context, option_autoremove, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
-	/* Apply options to context */
+	/* apply options to context */
 	pkgc_manage_apply_options (ctx);
 
 	if (argc >= 2) {
-		/* Update specific packages */
+		/* update specific packages */
+		g_auto(GStrv) package_ids = NULL;
+
+		pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NOT_INSTALLED);
+		pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NOT_SOURCE);
+		pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NEWEST);
+
+		package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
+		if (package_ids == NULL) {
+			if (error)
+				pkgc_print_error (ctx,
+						  _("Could not find packages to update: %s"), error->message);
+			return PKGC_EXIT_FAILURE;
+		}
+
 		pk_task_update_packages_async (PK_TASK (ctx->task),
-					       argv + 1,
+					       package_ids,
 					       ctx->cancellable,
 					       pkgc_context_on_progress_cb,
 					       ctx,
 					       pkgc_manage_on_task_finished_cb,
 					       ctx);
 	} else {
-		/* Update all packages - get updates first */
+		/* update all packages - get updates first */
 		g_autoptr(PkResults) results = NULL;
 		g_autoptr(PkPackageSack) sack = NULL;
 		g_auto(GStrv) package_ids = NULL;
 
-		/* Clear any previous error */
+		/* clear any previous error */
 		g_clear_error (&error);
 
-		/* Get current updates */
+		/* get current updates */
+		pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NEWEST);
 		results = pk_task_get_updates_sync (PK_TASK (ctx->task),
 						    ctx->filters,
 						    ctx->cancellable,
@@ -495,19 +538,22 @@ pkgc_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 						    &error);
 		if (results == NULL) {
 			pkgc_print_error (ctx, _("Failed to get updates: %s"), error->message);
-			ctx->exit_code = PKGCTL_EXIT_FAILURE;
+			ctx->exit_code = PKGC_EXIT_FAILURE;
 			return ctx->exit_code;
 		}
 
+		/* drop blocked packages from the update set */
 		sack = pk_results_get_package_sack (results);
+		pk_package_sack_remove_by_filter (sack, &pkgc_update_system_filter_helper, NULL);
+
 		package_ids = pk_package_sack_get_ids (sack);
 
 		if (package_ids == NULL || g_strv_length (package_ids) == 0) {
 			pkgc_print_info (ctx, _("No packages require updating"));
-			return PKGCTL_EXIT_SUCCESS;
+			return PKGC_EXIT_SUCCESS;
 		}
 
-		/* Now update them */
+		/* now update them */
 		pk_task_update_packages_async (PK_TASK (ctx->task),
 					       package_ids,
 					       ctx->cancellable,
@@ -527,7 +573,7 @@ pkgc_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Upgrade the system to a new distribution version or do an advanced update.
  */
 static gint
-pkgc_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_upgrade (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	const char *distro_name = NULL;
@@ -540,14 +586,13 @@ pkgc_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[DISTRO] [TYPE]",
-		/* TRANSLATORS: Description of pkgctl upgrade.
+		/* TRANSLATORS: Description of pkgcli upgrade.
 		 * No not translate "minimal, default, complete", those are parameters */
 		_("Upgrade all packages or perform a distribution upgrade.\n\n"
 		  "Types: minimal, default, complete"));
-	g_option_context_add_main_entries (option_context, option_autoremove, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Apply options to context */
 	pkgc_manage_apply_options (ctx);
@@ -594,7 +639,7 @@ pkgc_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 						    &error);
 		if (results == NULL) {
 			pkgc_print_error (ctx, _("Failed to get updates: %s"), error->message);
-			ctx->exit_code = PKGCTL_EXIT_FAILURE;
+			ctx->exit_code = PKGC_EXIT_FAILURE;
 			return ctx->exit_code;
 		}
 
@@ -603,7 +648,7 @@ pkgc_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 
 		if (package_ids == NULL || g_strv_length (package_ids) == 0) {
 			pkgc_print_info (ctx, _("No packages require updating"));
-			return PKGCTL_EXIT_SUCCESS;
+			return PKGC_EXIT_SUCCESS;
 		}
 
 		/* Now update them */
@@ -626,7 +671,7 @@ pkgc_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Helper for pkgc_offline_update().
  */
 static gint
-pkgc_print_offline_update_status (PkgctlContext *ctx)
+pkgc_print_offline_update_status (PkgcliContext *ctx)
 {
 	g_autoptr(GError) error = NULL;
 	g_autoptr(PkResults) results = NULL;
@@ -639,11 +684,11 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 	action = pk_offline_get_action (&error);
 	if (action == PK_OFFLINE_ACTION_UNKNOWN) {
 		pkgc_print_error (ctx, _("Failed to read offline update action: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
 	if (action == PK_OFFLINE_ACTION_UNSET) {
-		if (ctx->output_mode != PKGCTL_MODE_JSON)
+		if (ctx->output_mode != PKGCLI_MODE_JSON)
 			g_print ("%s%s%s",
 				 pkgc_get_ansi_color (ctx, PKGC_COLOR_BLUE),
 				 "⏾ ",
@@ -651,7 +696,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 		pkgc_print_info (ctx, _("Offline update is not triggered."));
 		g_print ("\n");
 	} else {
-		if (ctx->output_mode != PKGCTL_MODE_JSON)
+		if (ctx->output_mode != PKGCLI_MODE_JSON)
 			g_print ("%s%s%s",
 				 pkgc_get_ansi_color (ctx, PKGC_COLOR_YELLOW),
 				 "⚠ ",
@@ -670,7 +715,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 		pkgc_print_info (ctx, _("Prepared packages:"));
 		for (guint i = 0; package_ids[i] != NULL; i++) {
 			g_autofree gchar *printable = pk_package_id_to_printable (package_ids[i]);
-			if (ctx->output_mode == PKGCTL_MODE_JSON) {
+			if (ctx->output_mode == PKGCLI_MODE_JSON) {
 				json_t *root = json_object ();
 				json_object_set_new (root, "pkid", json_string (package_ids[i]));
 				pkgc_print_json_decref (root);
@@ -684,7 +729,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 			pkgc_print_info (ctx, _("No offline update is prepared."));
 		} else {
 			pkgc_print_error (ctx, _("Failed to read prepared offline updates: %s"), error->message);
-			return PKGCTL_EXIT_FAILURE;
+			return PKGC_EXIT_FAILURE;
 		}
 	}
 
@@ -694,7 +739,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 
 	if (!results) {
 		pkgc_print_info (ctx, _("No results from last offline update available."));
-		return PKGCTL_EXIT_SUCCESS;
+		return PKGC_EXIT_SUCCESS;
 	}
 
 	pk_error = pk_results_get_error_code (results);
@@ -703,7 +748,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 				  _("Last offline update failed: %s: %s"),
 					pk_error_enum_to_string (pk_error_get_code (pk_error)),
 					pk_error_get_details (pk_error));
-		return PKGCTL_EXIT_TRANSACTION_FAILED;
+		return PKGC_EXIT_TRANSACTION_FAILED;
 	}
 
 	packages = pk_results_get_package_array (results);
@@ -712,7 +757,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 		PkPackage *pkg = PK_PACKAGE (g_ptr_array_index (packages, i));
 		g_autofree gchar *printable = pk_package_id_to_printable (
 			pk_package_get_id (pkg));
-		if (ctx->output_mode == PKGCTL_MODE_JSON) {
+		if (ctx->output_mode == PKGCLI_MODE_JSON) {
 			json_t *root = json_object ();
 			json_object_set_new (root, "pkid", json_string (pk_package_get_id (pkg)));
 			pkgc_print_json_decref (root);
@@ -723,7 +768,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
 		}
 	}
 
-	return PKGCTL_EXIT_SUCCESS;
+	return PKGC_EXIT_SUCCESS;
 }
 
 /**
@@ -732,7 +777,7 @@ pkgc_print_offline_update_status (PkgctlContext *ctx)
  * Helper for pkgc_offline_update().
  */
 static gint
-pkgc_trigger_offline_update (PkgctlContext *ctx)
+pkgc_trigger_offline_update (PkgcliContext *ctx)
 {
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
@@ -740,11 +785,11 @@ pkgc_trigger_offline_update (PkgctlContext *ctx)
 	ret = pk_offline_trigger_with_flags (PK_OFFLINE_ACTION_REBOOT, PK_OFFLINE_FLAGS_INTERACTIVE, NULL, &error);
 	if (!ret) {
 		pkgc_print_error (ctx, _("Failed to trigger offline update: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
 	pkgc_print_success (ctx, _("Offline update scheduled. System will update on next reboot."));
-	return PKGCTL_EXIT_SUCCESS;
+	return PKGC_EXIT_SUCCESS;
 }
 
 /**
@@ -753,7 +798,7 @@ pkgc_trigger_offline_update (PkgctlContext *ctx)
  * Manage offline updates (for update installation on next (soft)reboot).
  */
 static gint
-pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_offline_update (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	const gchar *cmd_description = NULL;
@@ -761,7 +806,7 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
 
-	/* TRANSLATORS: Description of the pkgctl offline-update command.
+	/* TRANSLATORS: Description of the pkgcli offline-update command.
 	 * The request values (trigger, prepare, etc.) are parameters and MUST NOT be translated. */
 	cmd_description = _("Trigger & manage offline system updates.\n\n"
 						"You can select one of these requests:\n"
@@ -776,7 +821,7 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 		"[REQUEST]",
 		cmd_description);
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	request = (argc >= 2)? argv[1] : "prepare";
 
@@ -788,11 +833,11 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 		ret = pk_offline_cancel_with_flags (PK_OFFLINE_FLAGS_INTERACTIVE, NULL, &error);
 		if (!ret) {
 			pkgc_print_error (ctx, _("Failed to cancel offline update: %s"), error->message);
-			return PKGCTL_EXIT_FAILURE;
+			return PKGC_EXIT_FAILURE;
 		}
 
 		pkgc_print_success (ctx, _("Offline update cancelled"));
-		return PKGCTL_EXIT_SUCCESS;
+		return PKGC_EXIT_SUCCESS;
 	}
 
 	if (g_strcmp0 (request, "status") == 0) {
@@ -820,7 +865,7 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 							&error);
 		if (results == NULL) {
 			pkgc_print_error (ctx, _("Failed to get updates: %s"), error->message);
-			ctx->exit_code = PKGCTL_EXIT_FAILURE;
+			ctx->exit_code = PKGC_EXIT_FAILURE;
 			return ctx->exit_code;
 		}
 
@@ -828,7 +873,7 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 		package_ids = pk_package_sack_get_ids (sack);
 		if (package_ids == NULL || g_strv_length (package_ids) == 0) {
 			pkgc_print_info (ctx, _("No packages require updating"));
-			return PKGCTL_EXIT_SUCCESS;
+			return PKGC_EXIT_SUCCESS;
 		}
 
 		/* download packages */
@@ -842,14 +887,14 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
 		g_main_loop_run (ctx->loop);
 
 		/* don't trigger offline update if download failed */
-		if (ctx->exit_code != PKGCTL_EXIT_SUCCESS)
+		if (ctx->exit_code != PKGC_EXIT_SUCCESS)
 			return ctx->exit_code;
 
 		return pkgc_trigger_offline_update (ctx);
 	}
 
 	pkgc_print_error (ctx, _("Unknown offline-update request: %s"), request);
-	return PKGCTL_EXIT_SYNTAX_ERROR;
+	return PKGC_EXIT_SYNTAX_ERROR;
 }
 
 /**
@@ -858,7 +903,7 @@ pkgc_offline_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **
  * Install a package signature (for GPG verification).
  */
 static gint
-pkgc_install_sig (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_install_sig (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GOptionContext) option_context = NULL;
@@ -867,11 +912,11 @@ pkgc_install_sig (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **arg
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"TYPE KEY_ID PACKAGE_ID",
-		/* TRANSLATORS: Description for pkgctl install-sig */
+		/* TRANSLATORS: Description for pkgcli install-sig */
 		_("Install a package signature for GPG verification."));
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 4))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Install signature */
 	pk_client_install_signature_async (PK_CLIENT (ctx->task),
@@ -894,7 +939,7 @@ pkgc_install_sig (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **arg
  * Repair broken package management.
  */
 static gint
-pkgc_repair (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_repair (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 
@@ -902,11 +947,11 @@ pkgc_repair (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl repair */
+		/* TRANSLATORS: Description for pkgcli repair */
 		_("Attempt to repair the package management system."));
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* repair system */
 	pk_task_repair_system_async (PK_TASK (ctx->task),
@@ -918,7 +963,7 @@ pkgc_repair (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 
 	g_main_loop_run (ctx->loop);
 
-	if (ctx->exit_code == PKGCTL_EXIT_SUCCESS)
+	if (ctx->exit_code == PKGC_EXIT_SUCCESS)
 		pkgc_print_success (ctx, _("System repaired successfully"));
 
 	return ctx->exit_code;
@@ -930,7 +975,7 @@ pkgc_repair (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * Suggest to safely stop the PackageKit daemon.
  */
 static gint
-pkgc_suggest_quit (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_suggest_quit (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_autoptr(GError) error = NULL;
@@ -939,18 +984,18 @@ pkgc_suggest_quit (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl quit */
+		/* TRANSLATORS: Description for pkgcli quit */
 		_("Safely terminate the PackageKit daemon."));
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	if (!pk_control_suggest_daemon_quit (ctx->control, ctx->cancellable, &error)) {
 		pkgc_print_error (ctx, _("Failed to send daemon quit request: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
-	return PKGCTL_EXIT_SUCCESS;
+	return PKGC_EXIT_SUCCESS;
 }
 
 /**
@@ -959,7 +1004,7 @@ pkgc_suggest_quit (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
  * Register package management commands
  */
 void
-pkgc_register_manage_commands (PkgctlContext *ctx)
+pkgc_register_manage_commands (PkgcliContext *ctx)
 {
 	pkgc_context_register_command (
 		ctx,
