@@ -34,7 +34,7 @@
 static void
 pkgc_query_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-	PkgctlContext *ctx = user_data;
+	PkgcliContext *ctx = user_data;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(PkResults) results = NULL;
 	g_autoptr(GPtrArray) array = NULL;
@@ -46,7 +46,7 @@ pkgc_query_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpoin
 
 	if (error) {
 		pkgc_print_error (ctx, "%s", error->message);
-		ctx->exit_code = PKGCTL_EXIT_FAILURE;
+		ctx->exit_code = PKGC_EXIT_FAILURE;
 		g_main_loop_quit (ctx->loop);
 		return;
 	}
@@ -80,7 +80,7 @@ pkgc_query_on_task_finished_cb (GObject *source_object, GAsyncResult *res, gpoin
 		package_id = pk_files_get_package_id (files);
 		filelist = pk_files_get_files (files);
 
-		if (ctx->output_mode == PKGCTL_MODE_JSON) {
+		if (ctx->output_mode == PKGCLI_MODE_JSON) {
 			json_t *root;
 			json_t *files_array;
 
@@ -111,7 +111,7 @@ out:
 static void
 pkgc_query_on_client_finished_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-	PkgctlContext *ctx = user_data;
+	PkgcliContext *ctx = user_data;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(PkResults) results = NULL;
 
@@ -122,7 +122,7 @@ pkgc_query_on_client_finished_cb (GObject *source_object, GAsyncResult *res, gpo
 
 	if (error) {
 		pkgc_print_error (ctx, "%s", error->message);
-		ctx->exit_code = PKGCTL_EXIT_FAILURE;
+		ctx->exit_code = PKGC_EXIT_FAILURE;
 
 		goto out;
 	}
@@ -149,7 +149,7 @@ out:
  * Show system status.
  */
 static gint
-pkgc_backend_info (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_backend_info (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_autofree gchar *backend_name = NULL;
@@ -162,10 +162,10 @@ pkgc_backend_info (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl backend */
+		/* TRANSLATORS: Description for pkgcli backend */
 		_("Show PackageKit backend information."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* get control properties */
 	g_object_get (ctx->control,
@@ -181,7 +181,7 @@ pkgc_backend_info (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 
 	roles_str = pk_role_bitfield_to_string (roles);
 
-	if (ctx->output_mode == PKGCTL_MODE_JSON) {
+	if (ctx->output_mode == PKGCLI_MODE_JSON) {
 		json_t *root;
 		json_t *backend_obj;
 
@@ -223,7 +223,7 @@ pkgc_backend_info (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 		}
 	}
 
-	return PKGCTL_EXIT_SUCCESS;
+	return PKGC_EXIT_SUCCESS;
 }
 
 /**
@@ -232,7 +232,7 @@ pkgc_backend_info (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
  * Print transaction history.
  */
 static gint
-pkgc_history (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_history (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	guint limit = 10;
@@ -241,10 +241,10 @@ pkgc_history (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[LIMIT]",
-		/* TRANSLATORS: Description for pkgctl history */
+		/* TRANSLATORS: Description for pkgcli history */
 		_("Show recent package management transactions."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Parse optional limit */
 	if (argc >= 2) {
@@ -271,7 +271,7 @@ pkgc_history (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
  * pkgc_query_search:
  */
 static gint
-pkgc_query_search (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_search (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	const gchar *search_mode = "details";
 	const gchar **search_terms;
@@ -280,7 +280,7 @@ pkgc_query_search (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GOptionContext) option_context = NULL;
 
-	/* TRANSLATORS: Description of the pkgctl search command. MODE values must not be translated! */
+	/* TRANSLATORS: Description of the pkgcli search command. MODE values must not be translated! */
 	cmd_description = _("Search for packages matching the given patterns. If MODE is not specified, \n"
 						"'details' search is performed.\n"
 						"Possible search MODEs are:\n"
@@ -294,7 +294,7 @@ pkgc_query_search (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 												  "[MODE] PATTERN...",
 												  cmd_description);
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Check if first argument is a search type */
 	if (argc >= 3 && (strcmp (argv[1], "name") == 0 || strcmp (argv[1], "details") == 0 ||
@@ -309,7 +309,7 @@ pkgc_query_search (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
 
 	if (search_count == 0) {
 		pkgc_print_error (ctx, _("No search pattern specified"));
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 	}
 
 	/* Perform search based on type */
@@ -359,7 +359,7 @@ pkgc_query_search (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **ar
  * pkgc_query_list:
  */
 static gint
-pkgc_query_list (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_list (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 
@@ -367,10 +367,10 @@ pkgc_query_list (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[PATTERN]",
-		/* TRANSLATORS: Description for pkgctl list */
+		/* TRANSLATORS: Description for pkgcli list */
 		_("List all packages or those matching a pattern."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* if patterns provided, search by name */
 	if (argc >= 2) {
@@ -401,7 +401,7 @@ pkgc_query_list (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
  * pkgc_query_show:
  */
 static gint
-pkgc_query_show (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_show (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_auto(GStrv) package_ids = NULL;
@@ -411,13 +411,13 @@ pkgc_query_show (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl show */
+		/* TRANSLATORS: Description for pkgcli show */
 		_("Show information about one or more packages."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* TODO: Do we support mixed local packages and remote ones? Local handling should be improved... */
-	if (g_file_test ((argv + 1)[0], G_FILE_TEST_EXISTS)) {
+	if (pkgc_is_local_package ((argv + 1)[0])) {
 		/* get details for local package files */
 		pk_client_get_details_local_async (PK_CLIENT (ctx->task),
 						   argv + 1,
@@ -426,7 +426,7 @@ pkgc_query_show (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
 						   ctx,
 						   pkgc_query_on_client_finished_cb,
 						   ctx);
-	} else{
+	} else {
 		package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 		if (package_ids == NULL) {
 			if (error) {
@@ -436,7 +436,7 @@ pkgc_query_show (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
 						  _("Could not find packages: %s"), error->message);
 			}
 
-			return PKGCTL_EXIT_FAILURE;
+			return PKGC_EXIT_FAILURE;
 		}
 
 		/* get package details */
@@ -459,7 +459,7 @@ pkgc_query_show (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv
  * Display which other packages this package depends on.
  */
 static gint
-pkgc_query_depends_on (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_depends_on (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	gboolean recursive = FALSE;
 	g_auto(GStrv) package_ids = NULL;
@@ -468,7 +468,7 @@ pkgc_query_depends_on (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
 
 	const GOptionEntry options[] = {
 		{ "recursive", 0, G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, &recursive,
-		  N_("Check dependencies recursively"), NULL },
+		  _("Check dependencies recursively"), NULL },
 		{ NULL, 0, 0, 0, NULL, NULL, NULL }
 	};
 
@@ -476,17 +476,17 @@ pkgc_query_depends_on (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl depends-on */
+		/* TRANSLATORS: Description for pkgcli depends-on */
 		_("Show dependencies for one or more packages."));
 	g_option_context_add_main_entries (option_context, options, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 	if (package_ids == NULL) {
 		pkgc_print_error (ctx, _("Could not resolve packages: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
 	/* get dependencies */
@@ -508,7 +508,7 @@ pkgc_query_depends_on (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
  * pkgc_query_what_provides:
  */
 static gint
-pkgc_query_what_provides (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_what_provides (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 
@@ -516,10 +516,10 @@ pkgc_query_what_provides (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gch
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"CAPABILITY...",
-		/* TRANSLATORS: Description for pkgctl what-provides */
+		/* TRANSLATORS: Description for pkgcli what-provides */
 		_("Show which packages provide the specified capability."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	pk_task_what_provides_async (PK_TASK (ctx->task),
 				     ctx->filters,
@@ -538,7 +538,7 @@ pkgc_query_what_provides (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gch
  * pkgc_query_files:
  */
 static gint
-pkgc_query_files (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_files (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_autoptr(GError) error = NULL;
@@ -547,13 +547,13 @@ pkgc_query_files (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **arg
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl files */
+		/* TRANSLATORS: Description for pkgcli files */
 		_("List all files contained in one or more packages."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* TODO: Do we support mixed local packages and remote ones? Local handling should be improved... */
-	if (g_file_test ((argv + 1)[0], G_FILE_TEST_EXISTS)) {
+	if (pkgc_is_local_package ((argv + 1)[0])) {
 		/* get file list from local package files */
 		pk_client_get_files_local_async (PK_CLIENT (ctx->task),
 						 argv + 1,
@@ -568,7 +568,7 @@ pkgc_query_files (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **arg
 		package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 		if (package_ids == NULL) {
 			pkgc_print_error (ctx, _("Could not resolve packages: %s"), error->message);
-			return PKGCTL_EXIT_FAILURE;
+			return PKGC_EXIT_FAILURE;
 		}
 
 		/* get files list */
@@ -591,7 +591,7 @@ pkgc_query_files (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **arg
 static void
 pkgc_on_updates_finished_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
-	PkgctlContext *ctx = user_data;
+	PkgcliContext *ctx = user_data;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(PkResults) results = NULL;
 
@@ -602,7 +602,7 @@ pkgc_on_updates_finished_cb (GObject *source_object, GAsyncResult *res, gpointer
 
 	if (error != NULL) {
 		pkgc_print_error (ctx, "%s", error->message);
-		ctx->exit_code = PKGCTL_EXIT_FAILURE;
+		ctx->exit_code = PKGC_EXIT_FAILURE;
 		g_main_loop_quit (ctx->loop);
 		return;
 	}
@@ -634,7 +634,7 @@ pkgc_on_updates_finished_cb (GObject *source_object, GAsyncResult *res, gpointer
  * pkgc_updates_list_updates:
  */
 static gint
-pkgc_updates_list_updates (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_updates_list_updates (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 
@@ -642,10 +642,10 @@ pkgc_updates_list_updates (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gc
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl list-updates */
+		/* TRANSLATORS: Description for pkgcli list-updates */
 		_("List all currently available package updates."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* get available updates */
 	pk_task_get_updates_async (PK_TASK (ctx->task),
@@ -664,7 +664,7 @@ pkgc_updates_list_updates (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gc
  * pkgc_updates_show_update:
  */
 static gint
-pkgc_updates_show_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_updates_show_update (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_auto(GStrv) package_ids = NULL;
@@ -674,15 +674,16 @@ pkgc_updates_show_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gch
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl show-update */
+		/* TRANSLATORS: Description for pkgcli show-update */
 		_("Show detailed information about the specified package update."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
+	pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_NOT_INSTALLED);
 	package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 	if (package_ids == NULL) {
 		pkgc_print_error (ctx, _("Could not resolve packages: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 
 	/* get update details for specific packages */
@@ -702,7 +703,7 @@ pkgc_updates_show_update (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gch
  * pkgc_query_resolve:
  */
 static gint
-pkgc_query_resolve (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_resolve (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	PkBitfield filters;
@@ -711,10 +712,10 @@ pkgc_query_resolve (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **a
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl resolve */
+		/* TRANSLATORS: Description for pkgcli resolve */
 		_("Resolve package names to package IDs."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* we run this without our default filters, unless the user has explicitly specified some */
 	filters = ctx->user_filters_set? ctx->filters : 0;
@@ -737,7 +738,7 @@ pkgc_query_resolve (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **a
  * pkgc_query_required_by:
  */
 static gint
-pkgc_query_required_by (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_required_by (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	gboolean recursive = FALSE;
 	g_auto(GStrv) package_ids = NULL;
@@ -746,7 +747,7 @@ pkgc_query_required_by (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
 
 	const GOptionEntry options[] = {
 		{ "recursive", 0, G_OPTION_FLAG_NONE, G_OPTION_ARG_NONE, &recursive,
-		  N_("Check dependencies recursively"), NULL },
+		  _("Check dependencies recursively"), NULL },
 		{ NULL, 0, 0, 0, NULL, NULL, NULL }
 	};
 
@@ -754,17 +755,18 @@ pkgc_query_required_by (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"PACKAGE...",
-		/* TRANSLATORS: Description for pkgctl required-by */
+		/* TRANSLATORS: Description for pkgcli required-by */
 		_("Show which packages require the specified packages."));
 	g_option_context_add_main_entries (option_context, options, NULL);
 
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 2))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
+	pk_bitfield_add (ctx->filters, PK_FILTER_ENUM_INSTALLED);
 	package_ids = pkgc_resolve_packages (ctx, ctx->filters, argv + 1, &error);
 	if (package_ids == NULL) {
-		pkgc_print_error (ctx, _("Could not resolve packages: %s"), error->message);
-		return PKGCTL_EXIT_FAILURE;
+		pkgc_print_error (ctx, _("Could not find packages: %s"), error->message);
+		return PKGC_EXIT_FAILURE;
 	}
 
 	/* get packages that require this package */
@@ -786,7 +788,7 @@ pkgc_query_required_by (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar
  * pkgc_query_organization:
  */
 static gint
-pkgc_query_organization (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_organization (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	g_autofree gchar *text = NULL;
@@ -796,10 +798,10 @@ pkgc_query_organization (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gcha
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl organization */
+		/* TRANSLATORS: Description for pkgcli organization */
 		_("List all available filters, groups and categories for package organization."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* print available filters */
 	g_print ("%s%s%s\n",
@@ -852,7 +854,7 @@ pkgc_query_organization (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gcha
  * pkgc_query_show_os_upgrade:
  */
 static gint
-pkgc_query_show_os_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_show_os_upgrade (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 
@@ -860,10 +862,10 @@ pkgc_query_show_os_upgrade (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, g
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		NULL,
-		/* TRANSLATORS: Description for pkgctl show-distro-upgrade */
+		/* TRANSLATORS: Description for pkgcli show-distro-upgrade */
 		_("Show distribution version upgrades, if any are available."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	/* Get available distribution upgrades */
 	pk_client_get_distro_upgrades_async (PK_CLIENT (ctx->task),
@@ -884,7 +886,7 @@ static void
 pkgc_query_get_time_since_action_cb (GObject *object, GAsyncResult *res, gpointer data)
 {
 	guint time_s;
-	PkgctlContext *ctx = (PkgctlContext *) data;
+	PkgcliContext *ctx = (PkgcliContext *) data;
 	g_autoptr(GError) error = NULL;
 
 	/* get the results */
@@ -896,7 +898,7 @@ pkgc_query_get_time_since_action_cb (GObject *object, GAsyncResult *res, gpointe
 		goto out;
 	}
 
-	if (ctx->output_mode == PKGCTL_MODE_JSON) {
+	if (ctx->output_mode == PKGCLI_MODE_JSON) {
 		json_t *root;
 
 		root = json_object ();
@@ -918,7 +920,7 @@ out:
  * Get time since last action.
  */
 static gint
-pkgc_query_last_time (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar **argv)
+pkgc_query_last_time (PkgcliContext *ctx, PkgcliCommand *cmd, gint argc, gchar **argv)
 {
 	g_autoptr(GOptionContext) option_context = NULL;
 	const gchar *value = NULL;
@@ -928,10 +930,10 @@ pkgc_query_last_time (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar *
 	option_context = pkgc_option_context_for_command (
 		ctx, cmd,
 		"[ROLE]",
-		/* TRANSLATORS: Description for pkgctl last-time */
+		/* TRANSLATORS: Description for pkgcli last-time */
 		_("Get time in seconds since the last specified action."));
 	if (!pkgc_parse_command_options (ctx, cmd, option_context, &argc, &argv, 1))
-		return PKGCTL_EXIT_SYNTAX_ERROR;
+		return PKGC_EXIT_SYNTAX_ERROR;
 
 	if (argc >= 2)
 		value = argv[1];
@@ -940,14 +942,14 @@ pkgc_query_last_time (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar *
 		pkgc_print_error (ctx,
 				/* TRANSLATORS: The user didn't specify what action to use */
 				 "%s", _("An action, e.g. 'update-packages' is required"));
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 	role = pk_role_enum_from_string (value);
 	if (role == PK_ROLE_ENUM_UNKNOWN) {
 		pkgc_print_error (ctx,
 				/* TRANSLATORS: The user specified an invalid action */
 			 "%s", _("A correct role is required"));
-		return PKGCTL_EXIT_FAILURE;
+		return PKGC_EXIT_FAILURE;
 	}
 	pk_control_get_time_since_action_async (ctx->control,
 						role,
@@ -962,7 +964,7 @@ pkgc_query_last_time (PkgctlContext *ctx, PkgctlCommand *cmd, gint argc, gchar *
  * pkgc_register_query_commands:
  */
 void
-pkgc_register_query_commands (PkgctlContext *ctx)
+pkgc_register_query_commands (PkgcliContext *ctx)
 {
 	pkgc_context_register_command (
 		ctx,
@@ -996,15 +998,21 @@ pkgc_register_query_commands (PkgctlContext *ctx)
 
 	pkgc_context_register_command (
 		ctx,
-		"depends-on",
+		"list-depends",
 		pkgc_query_depends_on,
-		_("Show package dependencies"));
+		_("List package dependencies"));
+
+	pkgc_context_register_command (
+		ctx,
+		"list-required-by",
+		pkgc_query_required_by,
+		_("List packages requiring this package"));
 
 	pkgc_context_register_command (
 		ctx,
 		"what-provides",
 		pkgc_query_what_provides,
-		_("Show packages providing a capability"));
+		_("List packages providing a capability"));
 
 	pkgc_context_register_command (
 		ctx,
@@ -1030,12 +1038,6 @@ pkgc_register_query_commands (PkgctlContext *ctx)
 		pkgc_query_resolve,
 		_("Resolve package names"));
 
-	pkgc_context_register_command (
-		ctx,
-		"required-by",
-		pkgc_query_required_by,
-		_("Show packages requiring this package"));
-
 	pkgc_context_register_command (
 		ctx,
 		"organization",
