@@ -33,6 +33,8 @@ from .enums import *
 PACKAGE_IDS_DELIM = '&'
 FILENAME_DELIM = '|'
 
+MAXUINT64 = (1 << 64) - 1
+
 def _to_unicode(txt, encoding='utf-8'):
     if isinstance(txt, str):
         if not isinstance(txt, str):
@@ -232,7 +234,7 @@ class PackageKitBaseBackend:
         sys.stdout.write(_to_utf8("data\t%s\n" % data))
         sys.stdout.flush()
 
-    def details(self, package_id, summary, package_license, group, desc, url, bytes):
+    def details(self, package_id, summary, package_license, group, desc, url, bytes: int | None = None, download_bytes: int | None = None):
         '''
         Send 'details' signal
         @param package_id: The package ID name, e.g. openoffice-clipart;2.6.22;ppc64;fedora
@@ -242,8 +244,16 @@ class PackageKitBaseBackend:
         @param desc: The multi line package description
         @param url: The upstream project homepage
         @param bytes: The size of the package, in bytes
+        @param download_bytes: The download size of the package, in bytes
         '''
-        sys.stdout.write(_to_utf8("details\t%s\t%s\t%s\t%s\t%s\t%s\t%ld\n" % (package_id, summary, package_license, group, desc, url, bytes)))
+
+        # Ensure sizes report as 'unknown' in pkgcli if not reported
+        if bytes is None:
+            bytes = MAXUINT64
+        if download_bytes is None:
+            download_bytes = MAXUINT64
+
+        sys.stdout.write(_to_utf8("details\t%s\t%s\t%s\t%s\t%s\t%s\t%ld\t%ld\n" % (package_id, summary, package_license, group, desc, url, bytes, download_bytes)))
         sys.stdout.flush()
 
     def files(self, package_id, file_list):
@@ -410,6 +420,13 @@ class PackageKitBaseBackend:
         '''
         self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
 
+    def upgrade_system(self, distro_id):
+        '''
+        Implement the {backend}-update-system functionality
+        Needed to be implemented in a sub class
+        '''
+        self.error(ERROR_NOT_SUPPORTED, "This function is not implemented in this backend", exit=False)
+
     def refresh_cache(self, force):
         '''
         Implement the {backend}-refresh_cache functionality
@@ -706,6 +723,9 @@ class PackageKitBaseBackend:
         elif cmd == 'get-categories':
             self.get_categories()
             self.finished()
+        elif cmd == 'upgrade-system':
+            self.upgrade_system(args[0])
+            self.finished()
         elif cmd == 'repair-system':
             self.repair_system(args[0])
             self.finished()
