@@ -45,7 +45,7 @@
  * The time in ms the backend waits after receiving Finished() before
  * propagating the signal to the other components.
  * This delay is required as some threads may take some time to cancel or a
- * spawned executable to disappear of the system DBUS.
+ * spawned executable to disappear of the system bus.
  */
 #define PK_BACKEND_FINISHED_TIMEOUT_GRACE	10 /* ms */
 
@@ -826,6 +826,7 @@ pk_backend_job_thread_create (PkBackendJob *job,
 	helper->backend = job->backend;
 	helper->func = func;
 	helper->user_data = user_data;
+	helper->destroy_func = destroy_func;
 
 	/* create a thread and unref it immediately as we do not need to join()
 	 * this at any stage */
