@@ -38,6 +38,7 @@
 
 
 #define PK_TRANSACTION_ERROR_INPUT_INVALID	14
+#define GET_DETAILS_TEST_DATA "details\tgimp;3.0.4-84;x86_64;Solus\tGNU Image Manipulation Program\tGPL-3.0-or-later\tmultimedia\tGIMP is a mature image editor.\thttps://www.gimp.org/\t"
 
 /** ver:1.0 ***********************************************************/
 static GMainLoop *_test_loop = NULL;
@@ -414,6 +415,22 @@ pk_test_backend_spawn_func (void)
 	ret = pk_backend_spawn_inject_data (backend_spawn, job, "allow-cancel\tbrian", NULL);
 	g_assert_true (!ret);
 
+	/* test pk_backend_spawn_inject_data details - valid (install size, download size) */
+	ret = pk_backend_spawn_inject_data (backend_spawn, job, GET_DETAILS_TEST_DATA "145158504\t20920696", NULL);
+	g_assert_true (ret);
+
+	/* test pk_backend_spawn_inject_data details - valid (huge install size, huge download size) - actual sizes from "0ad-data;0.27.0-11;x86_64;Solus" */
+	ret = pk_backend_spawn_inject_data (backend_spawn, job, GET_DETAILS_TEST_DATA "3526938164\t1368603575", NULL);
+	g_assert_true (ret);
+
+	/* test pk_backend_spawn_inject_data details - invalid (invalid size, valid download size) */
+	ret = pk_backend_spawn_inject_data (backend_spawn, job, GET_DETAILS_TEST_DATA "INVALID-SIZE\t1368603575", NULL);
+	g_assert_true (!ret);
+
+	/* test pk_backend_spawn_inject_data details - invalid (valid size, invalid download size) */
+	ret = pk_backend_spawn_inject_data (backend_spawn, job, GET_DETAILS_TEST_DATA "145158504\tINVALID-DOWNLOAD-SIZE", NULL);
+	g_assert_true (!ret);
+
 	/* convert proxy uri (bare) */
 	uri = pk_backend_convert_uri ("username:password@server:port");
 	g_assert_cmpstr (uri, ==, "http://username:password@server:port/");
